@@ -1,3 +1,18 @@
+/*/////////////////////////////////////////Extcalc////////////////////////////////////////////
+/////////////////////////////////Scientific Graphic Calculator////////////////////////////////
+
+File:         extcalc.cpp
+Author:       Rainer Strobel
+Email:        rainer1223@users.sourceforge.net
+Homepage:     http://extcalc-linux.sourceforge.net
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2, or (at your option)
+any later version.
+
+
+////////////////////////////////////////////////////////////////////////////////////////////*/
 #include "extcalc.h"
 
 
@@ -23,6 +38,14 @@ int main( int argc, char **argv ) {
 		a.installTranslator(&german);
 	else MessageBox("QT-Sprachpaket konnte nicht geladen werden");
 #endif
+	
+#ifdef LANGUAGE_FR
+	QTranslator french(NULL);
+
+	if(french.load("data/qt_fr.qm",INSTALLDIR))
+		a.installTranslator(&french);
+	else MessageBox("Error loading Qt language file");
+#endif
 
 //root		8730
 //Pi		960   (982)
@@ -44,6 +67,7 @@ void MainObject::closeEvent(QCloseEvent*e)
 {
 	writeConfigFile();
 	writeVarFile();
+	statistics->writeListsFile();
 	if(scripting->quitProgram())
 	{
 		e->accept();
@@ -201,6 +225,9 @@ int MainObject::readConfigFile()
 			fwrite("COMPLEX=false\n",14,1,configFile);
 			fwrite("TABLETYPE=normal\n",17,1,configFile);
 			fwrite("BASE=dec\n",9,1,configFile);
+			fwrite("STATSHOWLINES=false\n",20,1,configFile);
+			fwrite("STATSHOWPOINTS=true\n",20,1,configFile);
+			fwrite("STATAUTOCLEAR=true\n",19,1,configFile);
 			fwrite("SHOWWIN1=true\n",14,1,configFile);
 			fwrite("SHOWWIN2=false\n",15,1,configFile);
 			fwrite("SHOWWIN3=true\n",14,1,configFile);
@@ -241,13 +268,13 @@ int MainObject::readConfigFile()
 			
 			if(lstat(CONFIGFILE,&fileStat) != 0)
 			{
-				MessageBox(EXTCALCC_MSG3+QString(CONFIGFILE));
+				ErrorBox(EXTCALCC_MSG3+QString(CONFIGFILE)+"\n\n"+getErrorMessage());
 				return -3;
 			}
-				
+
 		}
 		else {
-			MessageBox(EXTCALCC_MSG1+QString(CONFIGFILE)+EXTCALCC_MSG2);
+			ErrorBox(EXTCALCC_MSG1+QString(CONFIGFILE)+"\n\n"+getErrorMessage());
 			ret=-2;
 		}
 	}
@@ -258,7 +285,7 @@ int MainObject::readConfigFile()
 	configFile = fopen(CONFIGFILE,"r");
 	if(configFile == NULL)
 	{
-		MessageBox(EXTCALCC_MSG3+QString(CONFIGFILE));
+		MessageBox(EXTCALCC_MSG3+QString(CONFIGFILE)+"\n\n"+getErrorMessage());
 		return -3;
 	}
 	char* cConfFile = new char[fileLen+1];
@@ -568,11 +595,7 @@ int MainObject::readConfigFile()
 			tableZSteps=50;
 		pref.prec3dSteps=tableZSteps;
 	}
-	
-	
-	
-	
-	
+
 	QString rasterStr=getConfigString(&confFile,"RASTER");
 	if(rasterStr.length()>0)
 	{
@@ -648,6 +671,28 @@ int MainObject::readConfigFile()
 		else pref.logNyquistSteps=true;
 	}	
 	
+	logStr=getConfigString(&confFile,"STATSHOWLINES");
+	if(logStr.length()>0)
+	{
+		if(logStr.lower() == "false")
+			pref.showStatLines=false;
+		else pref.showStatLines=true;
+	}
+	logStr=getConfigString(&confFile,"STATSHOWPOINTS");
+	if(logStr.length()>0)
+	{
+		if(logStr.lower() == "false")
+			pref.showStatPoints=false;
+		else pref.showStatPoints=true;
+	}
+	logStr=getConfigString(&confFile,"STATAUTOCLEAR");
+	if(logStr.length()>0)
+	{
+		if(logStr.lower() == "false")
+			pref.statAutoClear=false;
+		else pref.statAutoClear=true;
+	}
+	
 	QString graphType=getConfigString(&confFile,"GRAPHTYPE");
 	if(graphType.length()>0)
 	{
@@ -814,7 +859,7 @@ void MainObject::writeConfigFile()
 	configFile = fopen(CONFIGFILE,"w");
 	if(configFile == NULL)
 	{
-		MessageBox(EXTCALCC_MSG4+QString(CONFIGFILE));
+		MessageBox(EXTCALCC_MSG1+QString(CONFIGFILE)+"\n\n"+getErrorMessage());
 		return;
 	}
 	QString configuration="";
@@ -951,6 +996,18 @@ void MainObject::writeConfigFile()
 	if(pref.clearScriptMemory == true)
 		configuration+="true";
 	else configuration+="false";
+	configuration+="\nSTATSHOWLINES=";
+	if(pref.showStatLines == true)
+		configuration+="true";
+	else configuration+="false";
+	configuration+="\nSTATSHOWPOINTS=";
+	if(pref.showStatPoints == true)
+		configuration+="true";
+	else configuration+="false";
+	configuration+="\nSTATAUTOCLEAR=";
+	if(pref.statAutoClear == true)
+		configuration+="true";
+	else configuration+="false";
 	configuration+="\nTABLETYPE=";
 	if(pref.tableType==TABLENORMAL)
 		configuration+="normal";
@@ -974,7 +1031,7 @@ void MainObject::writeConfigFile()
 	else if(pref.base == DEC)
 		configuration+="dec";
 	configuration+="\n";
-	
+
 	for(int c=0; c<8;c++)
 	{
 		configuration+="SHOWWIN";
@@ -984,7 +1041,7 @@ void MainObject::writeConfigFile()
 			configuration+="true\n";
 		else configuration+="false\n";
 	}
-	
+
 	for(int c=0; c<20;c++)
 	{
 		configuration+=cleanConfigString("F"+QString::number(c+1),pref.functions[c]);
@@ -1076,7 +1133,7 @@ void MainObject::readVarFile()
 	FILE*varFile = fopen(VARSFILE,"r");
 	if(varFile == NULL)
 	{
-		MessageBox("Unable to read variables file: "+QString(CONFIGFILE));
+		MessageBox(EXTCALCH_STR21+QString(VARSFILE)+"\n\n"+getErrorMessage());
 		return;
 	}
 	char* cConfFile = new char[fileLen+1];
@@ -1174,7 +1231,7 @@ void MainObject::writeVarFile()
 	configFile = fopen(VARSFILE,"w");
 	if(configFile == NULL)
 	{
-		ErrorBox("Unable to write variables file: "+QString(VARSFILE));
+		ErrorBox(EXTCALCH_STR22+QString(VARSFILE)+"\n\n"+getErrorMessage());
 		return;
 	}
 	QString vars="";
@@ -1212,29 +1269,48 @@ void MainObject::writeVarFile()
 
 void MainObject::tabChangeSlot(QWidget*activeWidget)
 {
+	calculator->dockWindowSlot();
+	calculator2->dockWindowSlot();
+	graph->dockWindowSlot();
+	table->dockWindowSlot();
+	matrix->dockWindowSlot();
+	statistics->dockWindowSlot();
+	scripting->dockWindowSlot();
+	scriptIO->dockWindowSlot();
+
+
+	
 	if(activeWidget==(QWidget*)calculator || activeWidget==(QWidget*)calculator2)
 	{
 		mainMenu->setItemVisible(GRAPH,false);
 		mainMenu->setItemVisible(TABLE,false);
 		mainMenu->setItemVisible(SCRIPTM,false);
+		mainMenu->setItemVisible(STATISTICSM,false);
+		
 	}
 	else if(activeWidget==(QWidget*)graph)
 	{
 		mainMenu->setItemVisible(GRAPH,true);
 		mainMenu->setItemVisible(TABLE,false);
 		mainMenu->setItemVisible(SCRIPTM,false);
+		mainMenu->setItemVisible(STATISTICSM,false);
+
 	}
 	else if(activeWidget==(QWidget*)table)
 	{
 		mainMenu->setItemVisible(GRAPH,false);
 		mainMenu->setItemVisible(TABLE,true);
 		mainMenu->setItemVisible(SCRIPTM,false);
+		mainMenu->setItemVisible(STATISTICSM,false);
+
 	}
 	else if(activeWidget==(QWidget*)matrix)
 	{
 		mainMenu->setItemVisible(GRAPH,false);
 		mainMenu->setItemVisible(TABLE,false);
 		mainMenu->setItemVisible(SCRIPTM,false);
+		mainMenu->setItemVisible(STATISTICSM,false);
+
 		emit matrixEnterSignal();
 	}
 	else if(activeWidget==(QWidget*)scripting || activeWidget==(QWidget*)scriptIO)
@@ -1242,6 +1318,15 @@ void MainObject::tabChangeSlot(QWidget*activeWidget)
 		mainMenu->setItemVisible(GRAPH,false);
 		mainMenu->setItemVisible(TABLE,false);
 		mainMenu->setItemVisible(SCRIPTM,true);
+		mainMenu->setItemVisible(STATISTICSM,false);
+	}
+	else if(activeWidget==(QWidget*)statistics)
+	{
+		mainMenu->setItemVisible(GRAPH,false);
+		mainMenu->setItemVisible(TABLE,false);
+		mainMenu->setItemVisible(SCRIPTM,false);
+		mainMenu->setItemVisible(STATISTICSM,true);
+
 	}
 	
 	if(activeWidget!=(QWidget*)calculator && activeWidget!=(QWidget*)calculator2)
@@ -1324,6 +1409,9 @@ void MainObject::helpMenuSlot(int item)
 #endif
 #ifdef LANGUAGE_EN
 		helpProcess->addArgument(QString(INSTALLDIR)+"/doc/help_en.html");
+#endif
+#ifdef LANGUAGE_FR
+		helpProcess->addArgument(QString(INSTALLDIR)+"/doc/help_fr.html");
 #endif
 		helpProcess->start();
 		break;
@@ -1468,6 +1556,31 @@ void MainObject::scriptMenuSlot(int item)
 	}
 }
 
+void MainObject::statisticsMenuSlot(int item)
+{
+	switch(item)
+	{
+		case STATCLEAR:
+			emit removeGraphicsLinesSignal();
+			graph->drawSlot();
+			break;
+		case STATAUTOCLEAR:
+			pref.statAutoClear=!pref.statAutoClear;
+			getPref(pref);
+			break;
+		case STATPOINTS:
+			pref.showStatPoints=!pref.showStatPoints;
+			getPref(pref);
+			break;
+		case STATLINES:
+			pref.showStatLines=!pref.showStatLines;
+			getPref(pref);
+			break;
+	}
+	
+}
+
+
 void MainObject::tableTypeMenuSlot(int item)
 {
 
@@ -1587,8 +1700,7 @@ void MainObject::viewMenuSlot(int item)
 			}
 			break;
 		case VIEWSTATISTICS:
-			//pref.showWindows[5]=!pref.showWindows[5];
-			pref.showWindows[5]=false;
+			pref.showWindows[5]=!pref.showWindows[5];
 			getPref(pref);
 			if(pref.showWindows[5])
 				showPage(statistics);
@@ -1648,6 +1760,53 @@ void MainObject::runScriptSlot(QString*)
 	else showPage(scriptIO);
 }
 
+void MainObject::changeTabSlot(int num)
+{
+	switch(num)
+	{
+		case 0:
+			if(!pref.showWindows[0])
+				viewMenuSlot(VIEWCALC1);
+			else showPage(calculator);
+			break;
+		case 1:
+			if(!pref.showWindows[1])
+				viewMenuSlot(VIEWCALC2);
+			else showPage(calculator2);
+			break;
+		case 2:
+			if(!pref.showWindows[2])
+				viewMenuSlot(VIEWGRAPH);
+			else showPage(graph);
+			break;
+		case 3:
+			if(!pref.showWindows[3])
+				viewMenuSlot(VIEWTABLE);
+			else showPage(table);
+			break;
+		case 4:
+			if(!pref.showWindows[4])
+				viewMenuSlot(VIEWMATRIX);
+			else showPage(matrix);
+			break;
+		case 5:
+			if(!pref.showWindows[5])
+				viewMenuSlot(VIEWSTATISTICS);
+			else showPage(statistics);
+			break;
+		case 6:
+			if(!pref.showWindows[6])
+				viewMenuSlot(VIEWSCRIPTING);
+			else showPage(scripting);
+			break;
+		case 7:
+			if(!pref.showWindows[7])
+				viewMenuSlot(VIEWSCRIPTIO);
+			else showPage(scriptIO);
+			break;
+	}
+}
+
 
 
 
@@ -1662,12 +1821,16 @@ void ImportDialog::saveSlot()
 {
 	QString savePath=savePathLine->text(),openPath=openPathLine->text();
 	
+	if(savePath.find("/") <0 && importFile)
+		savePath=pref.scriptPath+"/"+pref.scriptDirName+"/"+savePath;
+	
+	if(openPath.find("/") <0 && !importFile)
+		openPath=pref.scriptPath+"/"+pref.scriptDirName+"/"+openPath;
+	
 	if((savePath.find(pref.scriptPath+"/"+pref.scriptDirName) !=0 && importFile) || 
 		  (openPath.find(pref.scriptPath+"/"+pref.scriptDirName) !=0 && !importFile))
 	{
-		if(importFile)
-			ErrorBox(EXTCALCC_MSG6);
-		else ErrorBox(EXTCALCC_MSG7);
+		ErrorBox(EXTCALCC_MSG6+savePath);
 	}
 	else
 	{
@@ -1675,7 +1838,7 @@ void ImportDialog::saveSlot()
 		
 		if(lstat(savePath,&testStat)==0)
 		{
-			if(YesNoBox(EXTCALCC_MSG8)==1)
+			if(YesNoBox(EXTCALCC_MSG8+savePath)==1)
 				return;
 		}
 		system("cp -f "+openPath+" "+savePath);
