@@ -1,3 +1,21 @@
+/*/////////////////////////////////////////Extcalc////////////////////////////////////////////
+/////////////////////////////////Scientific Graphic Calculator////////////////////////////////
+
+File:         extcalc.h
+Author:       Rainer Strobel
+Email:        rainer1223@users.sourceforge.net
+Homepage:     http://extcalc-linux.sourceforge.net
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2, or (at your option)
+any later version.
+
+This file contains the main window class of extcalc and a class for the script import/export
+dialog, the todo list and the bug list.
+
+////////////////////////////////////////////////////////////////////////////////////////////*/
+
 #ifndef EXTCALCH
 #define EXTCALCH
 
@@ -12,6 +30,7 @@
 #include "scriptedit.h"
 #include "scriptio.h"
 #include "matrixwidget.h"
+#include "statistics.h"
 #include "global.h"
 #include <qtabwidget.h>
 #include <qtabbar.h>
@@ -92,11 +111,11 @@
 //      - type converting (int) (float) ...                                             ok  //
 //      - Arrays                                                                        ok  //
 //      - run other scripts: run                                                        ok  //
-//      - 2D-graph output functions: point, line, circle, ... (in a later version)          //
+//      - 2D-graph output functions: point, line, circle, ... (in a later version)      ok  //
 //      - OpenGL 3D-Graphics (in a later version)                                       ok  //
 //      - usage of files (in a later version)                                           ok  //
 //      - change preferences (in a later version)                                       ok  //
-//      - macros (in a later version)                                                       //
+//      - macros (in a later version)                                                   ok  //
 //      - script debugging tool                                                         ok  //
 //  - load and save scripts                                     (v0.5)                  ok  //
 //  - script editor window                                      (v0.5)                  ok  //
@@ -107,11 +126,25 @@
 //  - include matrix- vector- ...-functions to standard-parser  (v0.7)                  ok  //
 //  - window for vector calculations                            (v0.8)                  ok  //
 //  - window for matrix calculations                            (v0.8)                  ok  //
-//  - statistic functions                                       (v0.9 beta)                 //
+//  - statistic functions                                       (v0.9 beta)             ok  //
 //  - beta-tests, bugfixing, optimizing                         (v1.0 stable)               //
 /////////////////////////////////////////////TODO/////////////////////////////////////////////
 
 
+////////////////////////////////////////beta releases/////////////////////////////////////////
+//                                                                                          //
+//  - reorganisation of the checkString and script preprocessor functions               ok  //
+//  - optimization of the split and parse methods                                           //
+//  - change structure of exec and calc methods                                             //
+//  - standardized user interface design for all tabs                                   ok  //
+//  - open help file in default browser                                                     //
+//  - integrate constants list                                                              //
+//  - precise error messages                                                            ok  //
+//  - RPN                                                                                   //
+//  - Port to QT 4                                                                          //
+//  - use QTranslator for internationalization                                              //
+//                                                                                          //
+////////////////////////////////////////beta releases/////////////////////////////////////////
 
 
 /////////////////////////////////////////////bugs/////////////////////////////////////////////
@@ -149,6 +182,14 @@
 //	- array memory can't be deleted														ok	//
 //	- script load balancing doesn't work on fast (dual-core) CPUs						ok	//
 //	- inserting text into a running script doesn't work									ok	//
+//	- gl script programming does not work on every system									//
+//	- import script dialog path check is wrong											ok	//
+//	- bug in script console at selection												ok	//
+//	- file dialog in script preferences window is always in background					ok	//
+//	- view error when maximizing statistics tab											ok	//
+//	- directory creation at first start does not work									ok	//
+//	- command priority in script interpreter wrong										ok	//
+//	- autosize setting leads to wrong screenshot size									ok	//
 
 
 //////////////////////////used variables//////////////////////////
@@ -158,7 +199,7 @@
 //      |+/-      |  +/-308     |          1.7*10^15             |
 //      63       62             52                               0
 //
-//      Type: long double (12 Byte at 32bit CPU; 10 Bytes are used)
+//      Type: long double (12 Byte at 32bit CPU; 10 Bytes were used)
 //      sign         exponent            mantisse
 //      |+/-      |  +/-4932     |        1.2*10^18               |
 //      79        78             63            5                   0
@@ -170,6 +211,7 @@
 //		ca. 9 digits at integrations
 //		ca. 8 digits at differentiations
 
+
 //////////////////////////////Operations/////////////////////////////
 //
 //  binary operators:
@@ -184,7 +226,7 @@
 // asin acos atan
 // sinh cosh tanh
 // asinh acosh atanh
-// log ln
+// log ln exp
 // sqrt curt
 // not ~
 //
@@ -198,6 +240,7 @@
 // Variables A-Z
 // numbers 10 0.34 -34e-6 .456 34.e+43 hex4FA7C bin100010111 
 
+
 //////////////////////////////Parser:///////////////////////////////
 //                                                                //
 //                      2 - 5*6 + (6*4+3)                         //
@@ -222,7 +265,7 @@ class MainObject :public QTabWidget
 	QMenuBar*mainMenu;
 	QPopupMenu *calcMenu,*angleMenu,*helpMenu,*outputMenu,*floatPointMenu,*prefMenu,*graphMenu;
 	QPopupMenu *coordinateMenu,*graphTypeMenu,*calcTypeMenu,*baseMenu,*tableMenu,*tableTypeMenu;
-	QPopupMenu *editMenu,*viewMenu,*fileMenu,*scriptMenu;
+	QPopupMenu *editMenu,*viewMenu,*fileMenu,*scriptMenu,*statisticsMenu;
 	QTabBar*tabBar;
 	CalcWidget *calculator,*calculator2;
 	GraphWidget * graph;
@@ -236,7 +279,7 @@ class MainObject :public QTabWidget
 	ScriptWidget*scripting;
 	ScriptIOWidget*scriptIO;
 	MatrixWidget*matrix;
-	QWidget*statistics;
+	StatisticsWidget*statistics;
 	Preferences pref;
 	QProcess*helpProcess;
 	QTabDialog*infoDialog;
@@ -391,6 +434,9 @@ MainObject() :QTabWidget()
 	pref.tableAValue=0.0;
 	pref.tableXSteps=pref.tableZSteps=10;
 	pref.tableType=TABLENORMAL;
+	pref.statAutoClear=true;
+	pref.showStatLines=false;
+	pref.showStatPoints=true;
 	pref.showWindows[0]=pref.showWindows[2]=pref.showWindows[3]=pref.showWindows[4]=pref.showWindows[6]=true;
 	pref.showWindows[1]=pref.showWindows[5]=pref.showWindows[7]=false;
 
@@ -487,12 +533,12 @@ MainObject() :QTabWidget()
 	tableTypeMenu->insertItem(EXTCALCH_MENU40,TABLEPARAMETER);
 	tableTypeMenu->insertItem(EXTCALCH_MENU41,TABLEINEQUAITY);
 	tableTypeMenu->insertItem(EXTCALCH_MENU42,TABLE3D);
-	tableTypeMenu->insertItem("Complex",TABLECOMPLEX);
+	tableTypeMenu->insertItem(EXTCALCH_MENU78,TABLECOMPLEX);
 	QObject::connect(tableTypeMenu,SIGNAL(activated(int)),this,SLOT(tableTypeMenuSlot(int)));
 	
 	tableMenu=new QPopupMenu;
 	tableMenu->insertItem(EXTCALCH_MENU43,STANDARDTABLE);
-	tableMenu->insertItem("Reset Input Values",RESETTABLE);
+	tableMenu->insertItem(EXTCALCH_MENU68,RESETTABLE);
 	tableMenu->insertItem(EXTCALCH_MENU44,tableTypeMenu,TABLETYPE);
 	QObject::connect(tableMenu,SIGNAL(activated(int)),this,SLOT(tableMenuSlot(int)));
 
@@ -505,6 +551,14 @@ MainObject() :QTabWidget()
 	scriptMenu->insertItem(EXTCALCH_MENU65,CLEARMEMNOW);
 	QObject::connect(scriptMenu,SIGNAL(activated(int)),this,SLOT(scriptMenuSlot(int)));
 	
+	statisticsMenu=new QPopupMenu;
+	statisticsMenu->insertItem(EXTCALCH_MENU69,STATCLEAR);
+	statisticsMenu->insertItem(EXTCALCH_MENU70,STATAUTOCLEAR);
+	statisticsMenu->insertSeparator();
+	statisticsMenu->insertItem(EXTCALCH_MENU71,STATPOINTS);
+	statisticsMenu->insertItem(EXTCALCH_MENU72,STATLINES);
+	QObject::connect(statisticsMenu,SIGNAL(activated(int)),this,SLOT(statisticsMenuSlot(int)));
+	
 	prefMenu=new QPopupMenu;
 	prefMenu->insertItem(EXTCALCH_MENU10,CPREF);
 	prefMenu->insertItem(EXTCALCH_MENU11,GPREF);
@@ -528,8 +582,8 @@ MainObject() :QTabWidget()
 	viewMenu->insertItem(EXTCALCH_MENU53,VIEWCALC2);
 	viewMenu->insertItem(EXTCALCH_MENU54,VIEWGRAPH);
 	viewMenu->insertItem(EXTCALCH_MENU55,VIEWTABLE);
-	viewMenu->insertItem("Matrix/Vector",VIEWMATRIX);
-	viewMenu->insertItem("Statistics",VIEWSTATISTICS);
+	viewMenu->insertItem(EXTCALCH_MENU73,VIEWMATRIX);
+	viewMenu->insertItem(EXTCALCH_MENU74,VIEWSTATISTICS);
 	viewMenu->insertItem(EXTCALCH_MENU56,VIEWSCRIPTING);
 	viewMenu->insertItem(EXTCALCH_MENU61,VIEWSCRIPTIO);
 	QObject::connect(viewMenu,SIGNAL(activated(int)),this,SLOT(viewMenuSlot(int)));
@@ -548,6 +602,7 @@ MainObject() :QTabWidget()
 	mainMenu->insertItem(EXTCALCH_MENU17,graphMenu,GRAPH);
 	mainMenu->insertItem(EXTCALCH_MENU46,tableMenu,TABLE);
 	mainMenu->insertItem(EXTCALCH_MENU66,scriptMenu,SCRIPTM);
+	mainMenu->insertItem(EXTCALCH_MENU74,statisticsMenu,STATISTICSM);
 	mainMenu->insertItem(EXTCALCH_MENU18,helpMenu,HELP);
 	
 	
@@ -558,14 +613,14 @@ MainObject() :QTabWidget()
 
 	
 
-	calculator=new CalcWidget(this,pref,vars,threadData);
-	calculator2=new CalcWidget(this,pref,vars,threadData);
-	graph = new GraphWidget(this,pref,vars,threadData);
-	table=new TableWidget(this,pref,vars,threadData);
+	calculator=new CalcWidget(this,pref,vars,threadData,tabbarSize.bottom());
+	calculator2=new CalcWidget(this,pref,vars,threadData,tabbarSize.bottom());
+	graph = new GraphWidget(this,pref,vars,threadData,tabbarSize.bottom());
+	table=new TableWidget(this,pref,vars,threadData,tabbarSize.bottom());
 	scripting=new ScriptWidget(this,pref,vars,tabbarSize.bottom());
-	scriptIO=new ScriptIOWidget(this,pref,vars,graph->getShareContext());
+	scriptIO=new ScriptIOWidget(this,pref,vars,graph->getShareContext(),tabbarSize.bottom());
 	matrix=new MatrixWidget(this,pref,vars,threadData);
-	statistics=new QWidget(this);
+	statistics=new StatisticsWidget(this,pref,vars,threadData,tabbarSize.bottom());
 //	addTab(calculator,EXTCALCH_STR6);
 //	addTab(calculator2,EXTCALCH_STR7);
 //	addTab(graph,EXTCALCH_STR8);
@@ -589,6 +644,7 @@ MainObject() :QTabWidget()
 	QObject::connect(scripting,SIGNAL(prefChange(Preferences)),this,SLOT(getPref(Preferences)));
 	QObject::connect(scriptIO,SIGNAL(prefChange(Preferences)),this,SLOT(getPref(Preferences)));
 	QObject::connect(matrix,SIGNAL(prefChange(Preferences)),this,SLOT(getPref(Preferences)));
+	QObject::connect(statistics,SIGNAL(prefChange(Preferences)),this,SLOT(getPref(Preferences)));
 //	QObject::connect(statistics,SIGNAL(prefChange(Preferences)),this,SLOT(getPref(Preferences)));
 	QObject::connect(this,SIGNAL(currentChanged(QWidget*)),this,SLOT(tabChangeSlot(QWidget*)));
 	QObject::connect(this,SIGNAL(editSignal(int)),calculator,SLOT(editSlot(int)));
@@ -605,10 +661,15 @@ MainObject() :QTabWidget()
 	QObject::connect(this,SIGNAL(runScript(QString*)),scriptIO,SLOT(runScript(QString*)));
 	QObject::connect(this,SIGNAL(matrixEnterSignal()),matrix,SLOT(enterSlot()));
 	QObject::connect(tableMenu,SIGNAL(activated(int)),table,SLOT(tableMenuSlot(int)));
+	QObject::connect(statistics,SIGNAL(printSignal()),graph,SLOT(drawSlot()));
+	QObject::connect(statistics,SIGNAL(changeTabSignal(int)),this,SLOT(changeTabSlot(int)));
+	QObject::connect(statistics,SIGNAL(drawPointsSignal(long double*,int,bool)),graph,SIGNAL(drawPointsSignal(long double*,int,bool)));
+	QObject::connect(statistics,SIGNAL(removeLinesSignal()),graph,SIGNAL(removeLinesSignal()));
+	QObject::connect(graph,SIGNAL(statisticsRedrawSignal()),statistics,SLOT(redrawGraphSlot()));
+	QObject::connect(this,SIGNAL(removeGraphicsLinesSignal()),graph,SIGNAL(removeLinesSignal()));
+
 	
-	pref.scriptPath=getenv("HOME")+QString("/.extcalc/script");
-	pref.scriptDirName="code";
-	pref.dataDirName="data";
+
 	
 	
 	int ret=readConfigFile();
@@ -617,13 +678,15 @@ MainObject() :QTabWidget()
 		if(ret == -1)
 		{
 			//first start
-			ret=YesNoBox("Welcome to Extcalc!\n\nThis seems to be the first time, you start this program.\nFor this reason, Extcalc must create directories to store scripts and data.\nSay yes, if you want to change the script configuration!");
+			ret=YesNoBox(EXTCALCH_MENU75);
 		}
 		else if(ret==1)
 		{
-			ret=YesNoBox("Welcome To Extcalc 0.7.0!\n\nThis seems to be the first time, you start the new version of Extcalc.\nThe new version ships some script programs for matrix and vector arithmetics.\nThe script directories must exist to use them.\nSay yes, if you want to change the script configuration!");
+			ret=YesNoBox(EXTCALCH_MENU76);
 		}
-	
+		pref.scriptPath=getenv("HOME")+QString("/.extcalc/script/");
+		pref.scriptDirName="code";
+		pref.dataDirName="data";
 		if(ret==0)
 		{
 			if(scriptPref != NULL)
@@ -640,7 +703,7 @@ MainObject() :QTabWidget()
 			scriptPref=new ScriptPreferences(pref,(QWidget*)this);
 			QObject::connect(scriptPref,SIGNAL(prefChange(Preferences)),this,SLOT(getPref(Preferences)));
 			scriptPref->saveSlot();
-			MessageBox("Default directories created.");
+			MessageBox(EXTCALCH_MENU77);
 		}
 	}
 	readVarFile();
@@ -680,8 +743,10 @@ void helpMenuSlot(int item);
 void prefMenuSlot(int item);
 void tableMenuSlot(int item);
 void scriptMenuSlot(int item);
+void statisticsMenuSlot(int item);
 void tableTypeMenuSlot(int item);
 void runScriptSlot(QString*);
+void changeTabSlot(int);
 void getPref(Preferences newPref)
 {
 	static bool running=false;
@@ -754,9 +819,9 @@ void getPref(Preferences newPref)
 		if(pref.showWindows[3])
 			addTab(table,EXTCALCH_STR9);
 		if(pref.showWindows[4])
-			addTab(matrix,"Matrix/Vector");
+			addTab(matrix,EXTCALCH_MENU73);
 		if(pref.showWindows[5])
-			addTab(statistics,"Statistics");
+			addTab(statistics,EXTCALCH_MENU74);
 		if(pref.showWindows[6])
 			addTab(scripting,EXTCALCH_STR12);
 		if(pref.showWindows[7])
@@ -812,6 +877,7 @@ void getPref(Preferences newPref)
 	graph->setPref(pref);
 	table->setPref(pref);
 	matrix->setPref(pref);
+	statistics->setPref(pref);
 	scripting->setPref(pref);
 	scriptIO->setPref(pref);
 //	savePref(&pref);
@@ -826,6 +892,9 @@ void getPref(Preferences newPref)
 	graphTypeMenu->setItemChecked(pref.graphType,true);
 	tableTypeMenu->setItemChecked(pref.tableType,true);
 	scriptMenu->setItemChecked(CLEARMEMALWAYS,pref.clearScriptMemory);
+	statisticsMenu->setItemChecked(STATAUTOCLEAR,pref.statAutoClear);
+	statisticsMenu->setItemChecked(STATPOINTS,pref.showStatPoints);
+	statisticsMenu->setItemChecked(STATLINES,pref.showStatLines);
 	coordinateMenu->setItemChecked(SHOWAXES,pref.axis);
 	coordinateMenu->setItemChecked(SHOWLABELS,pref.label);
 	coordinateMenu->setItemChecked(SHOWRASTER,pref.raster);
@@ -844,6 +913,7 @@ signals:
 	void editSignal(int);
 	void runScript(QString*);
 	void matrixEnterSignal();
+	void removeGraphicsLinesSignal();
 
 };
 
