@@ -1,3 +1,18 @@
+/*/////////////////////////////////////////Extcalc////////////////////////////////////////////
+/////////////////////////////////Scientific Graphic Calculator////////////////////////////////
+
+File:         graphout.cpp
+Author:       Rainer Strobel
+Email:        rainer1223@users.sourceforge.net
+Homepage:     http://extcalc-linux.sourceforge.net
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2, or (at your option)
+any later version.
+
+
+////////////////////////////////////////////////////////////////////////////////////////////*/
 #include "graphout.h"
 
 
@@ -5,7 +20,8 @@
 
 void GraphOutput::initializeGL()
 {
-	glClearColor( 1.0,1.0,1.0,1.0 ); 
+	makeCurrent();
+	glClearColor( 1.0,1.0,1.0,1.0 );
 //	qglClearColor(white ); 
 	if(axes!=0xffffffff)
 		glDeleteLists(axes,1);
@@ -13,6 +29,7 @@ void GraphOutput::initializeGL()
 		axes=drawPolarAxes();
 	else if(pref.graphType==GRAPH3D)
 		axes=draw3dAxes();
+
 	else axes = drawStdAxes();
 	dynamicSteps=pref.dynamicSteps;
 	dynamicStart=pref.dynamicStart;
@@ -29,13 +46,17 @@ void GraphOutput::initializeGL()
 		generateTexture();
 	}
 	if(drawState!=DRAWNONE)
-	generateTexture();
-	
+		generateTexture();
 	
 	
 	glDisable(GL_TEXTURE_2D);
 	if(drawScreenshot)
 	{
+		if(hasStatisticsObjects)
+			emit statisticsRedrawSignal();
+		if(hasSolveObjects)
+			emit solveRedrawSignal();
+		
 		clearGL();
 		for(int c=0; c<20; c++)
 		{
@@ -739,7 +760,7 @@ void GraphOutput::wheelEvent(QWheelEvent*e)
 void GraphOutput::processStdFunction(QString function)
 {
 	char*func;
-	func = checkString(function,&pref);
+	func = preprocessor(&function,&pref,false);
 
 	double xStart,xStep;
 	xStart=pref.xmin;
@@ -747,6 +768,7 @@ void GraphOutput::processStdFunction(QString function)
 
 	QString num,num2;
 	Calculate ca1(NULL,func,&pref,vars);
+
 	struct timeval t1,t2;
 	
 	double* coordinates=new double[PRECISION2D*2+2];
@@ -774,14 +796,13 @@ void GraphOutput::processStdFunction(QString function)
 	}
 
 	objects.NewItem(generateGLList(index));
-	
 }
 
 
 void GraphOutput::processPolarFunction(QString function)
 {
 	char*func;
-	func = checkString(function,&pref);
+	func = preprocessor(&function,&pref,false);
 
 	double xStart,xStep;
 	xStart=0;
@@ -824,7 +845,7 @@ void GraphOutput::processPolarFunction(QString function)
 		seconds--;
 		usecs=1000000+usecs;
 	}
-	delete[]func;
+	free(func);
 	objects.NewItem(generateGLList(index));
 }
 
@@ -842,8 +863,8 @@ void GraphOutput::processParameterFunction(QString function)
 		f1=function.left(sep);
 		f2=function.right(function.length()-1-sep);
 	}
-	func1 = checkString(f1,&pref);
-	func2 = checkString(f2,&pref);
+	func1 = preprocessor(&f1,&pref,false);
+	func2 = preprocessor(&f2,&pref,false);
 
 	double xStart,xStep;
 	xStart=pref.parameterStart;
@@ -877,8 +898,8 @@ void GraphOutput::processParameterFunction(QString function)
 		usecs=1000000+usecs;
 	}
 	
-	delete[]func1;
-	delete[]func2;
+	free(func1);
+	free(func2);
 	objects.NewItem(generateGLList(index));
 }
 
@@ -924,7 +945,7 @@ void GraphOutput::process3dFunction(QString function)
 
 
 	char*func;
-	func = checkString(function,&pref);
+	func = preprocessor(&function,&pref,false);
 
 
 	double xStart,xStep,zStart,zStep;
@@ -1023,7 +1044,7 @@ void GraphOutput::process3dFunction(QString function)
 	}
 //	MessageBox(  "Sekunden:      "+QString::number(seconds)+
 //			   "\nMicrosekunden: "+QString::number(usecs));
-	delete[]func;
+	free(func);
 	GLuint newList=generateGLList(index);
 	delete[]coordinates;
 	objectCoordinates[objectCoordinates.GetLen()-1]=NULL;
@@ -1041,8 +1062,8 @@ void GraphOutput::processInequaityFunction(QString function1,QString function2,i
 	
 //    GLuint list;
 	char*func,*func2;
-	func = checkString(function1,&pref);
-	func2= checkString(function2,&pref);
+	func = preprocessor(&function1,&pref,false);
+	func2= preprocessor(&function2,&pref,false);
 	
 //	list = glGenLists( 1 );
 //	glNewList( list, GL_COMPILE );
@@ -1117,14 +1138,13 @@ void GraphOutput::processInequaityFunction(QString function1,QString function2,i
 	}
 //	MessageBox(  "Sekunden:      "+QString::number(seconds)+
 //			   "\nMicrosekunden: "+QString::number(usecs));
-//	delete[]func;
 	objects.NewItem(generateGLList(index));
 }
 
 void GraphOutput::processComplexFunction(QString function,bool draw3D=false)
 {
 	char*func;
-	func = checkString(function,&pref);
+	func = preprocessor(&function,&pref,false);
 
 	double zStart,zStep;
 	double* coordinates;
@@ -1423,7 +1443,8 @@ void GraphOutput::setPref(Preferences newPref)
 	currentSolvePrec=pref.solvePrec;
 	oldXMin=pref.xmin;
 	oldXMax=pref.xmax;
-	initializeGL();
+	if(!drawScreenshot)
+		initializeGL();
 }
 
 bool GraphOutput::updateFunctions(double oldXMin,double oldXMax)
@@ -1432,6 +1453,7 @@ bool GraphOutput::updateFunctions(double oldXMin,double oldXMax)
 	double xStart,xStep;
 	int steps,startStep;
 	bool ret=true;
+	makeCurrent();
 
 	if(pref.xmin>oldXMin)
 	{
@@ -1560,7 +1582,7 @@ bool GraphOutput::updateFunctions(double oldXMin,double oldXMax)
 
 void GraphOutput::processFunction(int index)
 {
-
+	makeCurrent();
 	oldXMin=pref.xmin;
 	oldXMax=pref.xmax;
 	
@@ -1568,7 +1590,7 @@ void GraphOutput::processFunction(int index)
 	if(index==ineq2)
 		return;
 	
-	if(pref.functionTypes[index]==GRAPH3D && pref.graphType!=GRAPH3D)
+	if((pref.functionTypes[index]==GRAPH3D || pref.functionTypes[index]==GRAPHCOMP3D) && pref.graphType!=GRAPH3D)
 		return;
 
 	if(!pref.dynamicFunctions[index])
@@ -2290,6 +2312,7 @@ void GraphOutput::drawHorizontalLine(double y)
 	glEndList();
 	additionalObjects.NewItem(list);
 	repaint();
+	hasSolveObjects=true;
 }
 
 
@@ -2306,6 +2329,7 @@ void GraphOutput::drawVerticalLine(double x)
 	glEndList();
 	additionalObjects.NewItem(list);
 	repaint();
+	hasSolveObjects=true;
 }
 
 void GraphOutput::drawCircle(double radius)
@@ -2323,6 +2347,7 @@ void GraphOutput::drawCircle(double radius)
 	glEndList();
 	additionalObjects.NewItem(list);
 	repaint();
+	hasSolveObjects=true;
 }
 void GraphOutput::drawPolarLine(double angle)
 {
@@ -2340,6 +2365,7 @@ void GraphOutput::drawPolarLine(double angle)
 	glEndList();
 	additionalObjects.NewItem(list);
 	repaint();
+	hasSolveObjects=true;
 }
 void GraphOutput::draw3dXLine(double y,double z)
 {
@@ -2356,6 +2382,7 @@ void GraphOutput::draw3dXLine(double y,double z)
 	glEndList();
 	additionalObjects.NewItem(list);
 	repaint();
+	hasSolveObjects=true;
 }
 
 void GraphOutput::draw3dYLine(double x,double z)
@@ -2373,8 +2400,7 @@ void GraphOutput::draw3dYLine(double x,double z)
 	glEndList();
 	additionalObjects.NewItem(list);
 	repaint();	
-	
-	
+	hasSolveObjects=true;
 }
 void GraphOutput::draw3dZLine(double x,double y)
 {
@@ -2391,6 +2417,38 @@ void GraphOutput::draw3dZLine(double x,double y)
 	glEndList();
 	additionalObjects.NewItem(list);
 	repaint();
+	hasSolveObjects=true;
+}
+
+void GraphOutput::drawPoints(long double *coordinates,int num,bool con)
+{
+	GLuint list;
+	list=glGenLists(1);
+	double step=PI/10;
+	double radiusX=(pref.xmax-pref.xmin)/200,radiusY=(pref.ymax-pref.ymin)/200;
+	
+	glNewList(list, GL_COMPILE);
+	qglColor(QColor(0,0,0));
+	for(int c1=0; c1<num; c1++)
+	{
+		glBegin(GL_LINE_STRIP);
+		for(int c=0; c<=20; c++)
+			glVertex3f(cos((double)c*step)*radiusX+coordinates[2*c1],sin((double)c*step)*radiusY+coordinates[2*c1+1],0.0f);
+		glEnd();
+	}
+	if(con)
+	{
+		qglColor(QColor(100,0,0));
+		glBegin(GL_LINE_STRIP);
+		for(int c=0; c<num; c++)
+				glVertex3f(coordinates[2*c],coordinates[2*c+1],0.0f);
+		glEnd();
+	}
+	glEndList();
+	additionalObjects.NewItem(list);
+	if(!drawScreenshot)
+		repaint();
+	hasStatisticsObjects=true;
 	
 }
 
@@ -2402,8 +2460,10 @@ void GraphOutput::removeLines()
 		glDeleteLists(additionalObjects[0],1);
 		additionalObjects.DeleteItem(0);
 	}
+	hasSolveObjects=hasStatisticsObjects=false;
 	ineq1=ineq2=-1;
-	repaint();
+	if(!drawScreenshot)
+		repaint();
 }
 
 void GraphOutput::resetRotation()
@@ -2514,6 +2574,9 @@ void GraphOutput::screenshotSlot(int x, int y)
 	scr=renderPixmap(x,y,false);
 	emit screenshotSignal(&scr);
 	drawScreenshot=false;
+	initializeGL();
+	repaint();
+
 }
 
 
