@@ -1,3 +1,18 @@
+/*/////////////////////////////////////////Extcalc////////////////////////////////////////////
+/////////////////////////////////Scientific Graphic Calculator////////////////////////////////
+
+File:         scriptedit.cpp
+Author:       Rainer Strobel
+Email:        rainer1223@users.sourceforge.net
+Homepage:     http://extcalc-linux.sourceforge.net
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2, or (at your option)
+any later version.
+
+
+////////////////////////////////////////////////////////////////////////////////////////////*/
 #include "scriptedit.h"
 
 
@@ -17,11 +32,12 @@ void ScriptWidget::resizeEvent(QResizeEvent*)
 	}
 	else {
 		splitter->setGeometry(20,50,width-40,height-290);
-		
-		runButton->setGeometry(width/2+15,height-220,90,35);
-		maximizeButton->setGeometry(width/2+115,height-220,90,35);
-		saveButton->setGeometry(width/2+215,height-220,90,35);
-		
+
+//		runButton->setGeometry(width/2+15,height-220,90,35);
+//		maximizeButton->setGeometry(width/2+115,height-220,90,35);
+//		saveButton->setGeometry(width/2+215,height-220,90,35);
+		dockArea->setGeometry(width/2+15,height-220,width/2-35,35);
+
 		standardButtons->setGeometry(20,height-220,280,200);
 		extButtons->setGeometry(width/2+10,height-180,300,160);
 
@@ -71,20 +87,33 @@ void ScriptWidget::maximizeButtonSlot()
 //		maximizeButton->setText(SCRIPTEDITC_STR1);
 		standardButtons->show();
 		extButtons->show();
-		dockArea->hide();
-		saveButton->show();
-		maximizeButton->show();
-		runButton->show();
+//		dockArea->hide();
+//		saveButton->show();
+//		maximizeButton->show();
+//		runButton->show();
+		saveallButton->hide();
+		cutButton->hide();
+		copyButton->hide();
+		pasteButton->hide();
+		importButton->hide();
+		exportButton->hide();
 
 	}
 	else {
 //		maximizeButton->setText(SCRIPTEDITC_STR2);
 		standardButtons->hide();
 		extButtons->hide();
-		dockArea->show();
-		saveButton->hide();
-		maximizeButton->hide();
-		runButton->hide();
+//		dockArea->show();
+//		saveButton->hide();
+//		maximizeButton->hide();
+//		runButton->hide();
+		saveallButton->show();
+		cutButton->show();
+		copyButton->show();
+		pasteButton->show();
+		importButton->show();
+		exportButton->show();
+
 
 	}
 	maximized=!maximized;
@@ -413,7 +442,7 @@ void ScriptWidget::fileBrowserMenuSlot(int item)
 				}
 				newPath+=newName;
 				if(rename(oldPath,newPath)!=0)
-					ErrorBox(SCRIPTEDITC_STR8);
+					ErrorBox(SCRIPTEDITC_STR8+clickedFileItem->text(0)+"\n\n"+getErrorMessage());
 				int slash=oldPath.findRev('/');
 				oldPath.insert(slash+1,".tmp");
 				slash=newPath.findRev('/');
@@ -437,10 +466,10 @@ void ScriptWidget::fileBrowserMenuSlot(int item)
 			if(clickedFileItem==NULL)
 				break;
 			QString path=getFileName(clickedFileItem);
-			if(YesNoBox(SCRIPTEDITC_STR9)==0)
+			if(YesNoBox(SCRIPTEDITC_STR9+path)==0)
 			{
 				if(remove(pref.scriptPath+"/"+pref.scriptDirName+"/"+path)!=0)
-					ErrorBox(SCRIPTEDITC_STR10);
+					ErrorBox(SCRIPTEDITC_STR10+path+"\n\n"+getErrorMessage());
 				updateFileList();
 			}
 			break;
@@ -471,13 +500,13 @@ void ScriptWidget::fileBrowserMenuSlot(int item)
 			struct stat testStat;
 			if(lstat(filePath,&testStat)==0)
 			{
-				if(YesNoBox(SCRIPTEDITC_STR15)==1)
+				if(YesNoBox(SCRIPTEDITC_STR15+filePath)==1)
 					break;
 			}
 			FILE*editorFile=fopen(filePath,"w");
 			if(editorFile==NULL)
 			{
-				ErrorBox(SCRIPTEDITC_STR16);
+				ErrorBox(SCRIPTEDITC_STR16+activeFileItem->text(0)+"\n\n"+getErrorMessage());
 				break;
 			}
 
@@ -680,7 +709,7 @@ void ScriptWidget::saveSlot()
 	
 	if(!saveFile(filePath,content))
 	{
-		ErrorBox(SCRIPTEDITC_STR25+filePath+".");
+		ErrorBox(SCRIPTEDITC_STR25+QString("\n\n")+filePath+"\n\n"+getErrorMessage());
 		return;
 	}
 	
@@ -708,7 +737,7 @@ void ScriptWidget::saveSlot()
 			activeFileItem->setPixmap(0,NULL);
 		currentTextChanged=false;
 	}
-	else MessageBox(SCRIPTEDITC_STR23);
+	else MessageBox(SCRIPTEDITC_STR23+filePath+"\n\n"+getErrorMessage());
 }
 
 
@@ -779,6 +808,11 @@ void ScriptWidget::runButtonSlot()
 	emit runScript(&txt);
 }
 
+void ScriptWidget::catalogSlot()
+{
+	catalog->exec(editorToolBar->mapToGlobal(QPoint(catalogButton->x(),catalogButton->y()+catalogButton->height())));
+}
+
 
 bool ScriptWidget::quitProgram()
 {
@@ -825,6 +859,11 @@ void ScriptWidget::importSlot()
 	emit controlScriptMenu(IMPORTSCRIPT);
 }
 
+void ScriptWidget::dockWindowSlot()
+{
+	dockArea->moveDockWindow(editorToolBar);
+}
+
 void ScriptWidget::exportSlot()
 {
 	emit controlScriptMenu(EXPORTSCRIPT);
